==> httpcomponents-client-5.2-alpha1-src.tar.gz: httpclient5-cache/src/test/java/org/apache/hc/client5/http/schedule/TestConcurrentCountMap.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.client5.http.schedule;

import org.hamcrest.CoreMatchers;
import org.hamcrest.MatcherAssert;
import org.junit.Test;

public class TestConcurrentCountMap
{

    private static final String IDENTIFIER = "some-identifier";

    private final ConcurrentCountMap<String> map = new ConcurrentCountMap<>();

    @Test
    public void testBasics() {
        map.increaseCount(IDENTIFIER);
        map.increaseCount(IDENTIFIER);
        MatcherAssert.assertThat(map.getCount(IDENTIFIER), CoreMatchers.equalTo(2));

        map.resetCount(IDENTIFIER);
        MatcherAssert.assertThat(map.getCount(IDENTIFIER), CoreMatchers.equalTo(0));
    }

}

==> httpcomponents-client-5.4-alpha1-src.tar.gz: httpclient5-cache/src/test/java/org/apache/hc/client5/http/schedule/TestConcurrentCountMap.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.client5.http.schedule;

import static org.hamcrest.MatcherAssert.assertThat;

import org.hamcrest.CoreMatchers;
import org.junit.jupiter.api.Test;

public class TestConcurrentCountMap
{

    private static final String IDENTIFIER = "some-identifier";

    private final ConcurrentCountMap<String> map = new ConcurrentCountMap<>();

    @Test
    public void testBasics() {
        map.increaseCount(IDENTIFIER);
        map.increaseCount(IDENTIFIER);
        assertThat(map.getCount(IDENTIFIER), CoreMatchers.equalTo(2));

        map.resetCount(IDENTIFIER);
        assertThat(map.getCount(IDENTIFIER), CoreMatchers.equalTo(0));
    }

}
